;****************************************************************************
;*
;*  Copyright (C) 1996 - 2001 Dallas Semiconductor Corporation. 
;*  All rights Reserved. Printed in U.S.A.
;*  This software is protected by copyright laws of
;*  the United States and of foreign countries.
;*  This material may also be protected by patent laws of the United States 
;*  and of foreign countries.
;*  This software is furnished under a license agreement and/or a
;*  nondisclosure agreement and may only be used or copied in accordance
;*  with the terms of those agreements.
;*  The mere transfer of this software does not imply any licenses
;*  of trade secrets, proprietary technology, copyrights, patents,
;*  trademarks, maskwork rights, or any other form of intellectual
;*  property whatsoever. Dallas Semiconductor retains all ownership rights.
;*
;*     Module Name: DS80C400 
;*
;*     Description: DS80C400 SFR Definitions
;*
;*        Filename: ds80c400.inc
;*
;****************************************************************************

; CAN Controller Registers
C0RMS0  EQU 096H            ; CAN Receive Message Stored Register Zero (1-8)
C0RMS1  EQU 097H            ; CAN Receive Message Stored Register One (9-15)
C0TMA0  EQU 09EH            ; CAN Transmit Message Acknowledgement Register Zero (1-8)
C0TMA1  EQU 09FH            ; CAN Transmit Message Acknowledgement Register One (9-15)
C0C     EQU 0A3H            ; CAN Control Register
C0S     EQU 0A4H            ; CAN Status Register
C0IR    EQU 0A5H            ; CAN Interrupt Register
C0TE    EQU 0A6H            ; CAN Transmit Error Register
C0RE    EQU 0A7H            ; CAN Receive Error Register
C0M1C   EQU 0ABH            ; CAN Message One Control Register
C0M2C   EQU 0ACH            ; CAN Message Two Control Register
C0M3C   EQU 0ADH            ; CAN Message Three Control Register
C0M4C   EQU 0AEH            ; CAN Message Four Control Register
C0M5C   EQU 0AFH            ; CAN Message Five Control Register
C0M6C   EQU 0B3H            ; CAN Message Six Control Register
C0M7C   EQU 0B4H            ; CAN Message Seven Control Register
C0M8C   EQU 0B5H            ; CAN Message Eight Control Register
C0M9C   EQU 0B6H            ; CAN Message Nine Control Register
C0M10C  EQU 0B7H            ; CAN Message Ten Control Register
C0M11C  EQU 0BBH            ; CAN Message Eleven Control Register
C0M12C  EQU 0BCH            ; CAN Message Twelve Control Register
C0M13C  EQU 0BDH            ; CAN Message Thirteen Control Register
C0M14C  EQU 0BEH            ; CAN Message Fourteen Control Register
C0M15C  EQU 0BFH            ; CAN Message Fifteen Control Register

;  BYTE Registers
SBUF0   EQU 099H

;  DS80C320 Extensions
DPL1    EQU 084H
DPH1    EQU 085H
DPS     EQU 086H
CKCON   EQU 08EH
EXIF    EQU 091H
SADDR0  EQU 0A9H
SADDR1  EQU 0AAH
SADEN0  EQU 0B9H
SADEN1  EQU 0BAH
SBUF1   EQU 0C1H
TA      EQU 0C7H
T2MOD   EQU 0C9H
RCAP2L  EQU 0CAH
RCAP2H  EQU 0CBH
TL2     EQU 0CCH
TH2     EQU 0CDH
EIP     EQU 0F8H
PMR	EQU 0C4H
STATUS  EQU 0C5h


; Register Banks
R0_B0   EQU 0                         ; Register bank 0 equates.
R1_B0   EQU 1
R2_B0   EQU 2
R3_B0   EQU 3
R4_B0   EQU 4
R5_B0   EQU 5
R6_B0   EQU 6
R7_B0   EQU 7
;
R0_B1   EQU 8                         ; Register bank 1 equates.
R1_B1   EQU 9
R2_B1   EQU 0AH 
R3_B1   EQU 0BH 
R4_B1   EQU 0CH 
R5_B1   EQU 0DH 
R6_B1   EQU 0EH 
R7_B1   EQU 0FH 
;
R0_B2   EQU 10H                       ; Register bank 2 equates.
R1_B2   EQU 11H 
R2_B2   EQU 12H 
R3_B2   EQU 13H
R4_B2   EQU 14H
R5_B2   EQU 15H
R6_B2   EQU 16H
R7_B2   EQU 17H
;
R0_B3   EQU 18H                       ; Register bank 3 equates.
R1_B3   EQU 19H
R2_B3   EQU 1AH
R3_B3   EQU 1BH
R4_B3   EQU 1CH
R5_B3   EQU 1DH
R6_B3   EQU 1EH
R7_B3   EQU 1FH

;  EQU Registers

; *** IE ***
ES1     EQU 0AEH
ET2     EQU 0ADH
ES0     EQU 0ACH

; *** IP ***
PS1     EQU 0BEH
PT2     EQU 0BDH
PS0     EQU 0BCH

; *** P1 ***
INT5    EQU 097H
INT4    EQU 096H
INT3    EQU 095H
INT2    EQU 094H
TXD1    EQU 093H
RXD1    EQU 092H
T2EX    EQU 091H
T2      EQU 090H

; *** P3 ***
TXD0    EQU 0B1H
RXD0    EQU 0B0H

; *** SCON1 ***
SM01    EQU 0C7H
SM11    EQU 0C6H
SM21    EQU 0C5H
REN1    EQU 0C4H
TB81    EQU 0C3H
RB81    EQU 0C2H
TI1     EQU 0C1H
RI1     EQU 0C0H

; *** T2CON ***
TF2     EQU 0CFH
EXF2    EQU 0CEH
RCLK    EQU 0CDH
TCLK    EQU 0CCH
EXEN2   EQU 0CBH
TR2     EQU 0CAH
C_T2    EQU 0C9H
CP_RL2  EQU 0C8H

; *** WDCON ***
SMOD    EQU 0DFH
POR     EQU 0DEH
EPFI    EQU 0DDH
PFI     EQU 0DCH
WDIF    EQU 0DBH
WDRF    EQU 0DAH
EWT     EQU 0D9H
RWT     EQU 0D8H

; *** EIE ***
EWDI    EQU 0ECH

; *** EIP ***
PWDI    EQU 0FCH
PX5     EQU 0FBH
PX4     EQU 0FAH
PX3     EQU 0F9H
PX2     EQU 0F8H

; **** Math Accelerator ****
MCNT0   EQU 0D1H
MCNT1   EQU 0D2H
MA      EQU 0D3H
MB      EQU 0D4H
MC      EQU 0D5H

; New registers in the 80C400
TM1	EQU 08FH
TM3	EQU 0E9H
P6	EQU 0B1H
P6CNT	EQU 0B2H
MCON1	EQU 0D6H
OCAD	EQU 0E1H
CSRD	EQU 0E3h
CSRA	EQU 0E4H
EBS	EQU 0E5H
BCUD	EQU 0E6H
BCUC	EQU 0E7H
DPX2	EQU 0EBH
DPX3	EQU 0EDH
DPL2	EQU 0F2H
DPH2	EQU 0F3H
DPL3	EQU 0F4H
DPH3	EQU 0F5H
DPS1	EQU 0F6H
P7	EQU 0F9H
TL3     EQU 0FBH
TH3     EQU 0FCH
T3CM    EQU 0FDH
SCON2   EQU 0FEH
SBUF2   EQU 0FFH

EX2_5   EQU EIE.0
ET3     EQU EIE.1
ES2     EQU EIE.2
EWPI    EQU EIE.3
EAIE	EQU EIE.5
C0IE    EQU EIE.6
EPMIE	EQU EIE.7

PT3     EQU EIP.1
PS2     EQU EIP.2
EAIP	EQU EIP.5
EPMIP	EQU EIP.7

RIF	EQU 10h
TIF	EQU 20h
EPMF	EQU 40h

OWMAD	EQU 0EEh
OWMDR	EQU 0EFh

; New registers in the 83C390
AP      EQU 09CH
ESP     EQU 09BH
DPX     EQU 093H
DPX1    EQU 095H
ACON    EQU 09DH
MCON    EQU 0C6H
P4CNT   EQU 092H
P5CNT   EQU 0A2H
P5      EQU 0A1H
MXAX    EQU 0EAH
COR     EQU 0CEH            ; Clock output Register
P4	EQU 80H

; Registers on the 80C520
F1      EQU PSW.1

